(defproject crypto-random "1.2.1"
  :description "Library for generating secure random bytes and strings"
  :url "https://github.com/weavejester/crypto-random"
  :license {:name "Eclipse Public License"
            :url "http://www.eclipse.org/legal/epl-v10.html"}
  :dependencies [[org.clojure/clojure "1.7.0"]
                 [commons-codec "1.15"]])
